<?php
// Version: 1.1; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '1.1 RC3';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = true;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = true;

	/* Show sticky and lock status seperate from topic icons? */
	$settings['seperate_sticky_lock'] = true;

	// Color changer
	if(!$context['user']['is_guest'] && isset($_POST['options']['theme_color']))
	{
	   include_once($GLOBALS['sourcedir'] . '/Profile.php');
	   makeThemeChanges($context['user']['id'], $settings['theme_id']);
	   $options['theme_color'] = $_POST['options']['theme_color'];
	}
	elseif ($context['user']['is_guest'])
	{
	   if (isset($_POST['options']['theme_color']))
	   {
		  $_SESSION['theme_color'] = $_POST['options']['theme_color'];
		  $options['theme_color'] = $_SESSION['theme_color'];
	   }
	   elseif (isset($_SESSION['theme_color']))
		  $options['theme_color'] = $_SESSION['theme_color'];
	}
}



// The main sub template above the content.
function template_main_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title'], '" />
	<meta name="keywords" content="PHP, MySQL, bulletin, board, free, open, source, smf, simple, machines, forum, esiz, mjorayulun, MJoRaYuLuN, smfdestek" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/script.js?rc2p"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
	// ]]></script>
	<title>', $context['page_title'], '</title>';

	// Any color set by user?
	if (isset($options['theme_color']))
		$settings['tema_rengi'] = $options['theme_color'];

	// If not set, or if not allowed to set
	if(!isset($options['theme_color']) || (isset($settings['allow_color_change']) && $settings['allow_color_change'] == 'no'))
	{
		// Defaults.
		$options['theme_color'] = isset($settings['tema_rengi']) ? $settings['tema_rengi'] : 'essiz';
		$settings['tema_rengi'] = $options['theme_color'];
	}

	// The ?fin11 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style.css?rc3" />
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style_' , $settings['tema_rengi'] , '.css?fin11" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/print.css?rc3" media="print" />';

	/* Internet Explorer 4/5 and Opera 6 just don't do font sizes properly. (they are big...)
		Thus, in Internet Explorer 4, 5, and Opera 6 this will show fonts one size smaller than usual.
		Note that this is affected by whether IE 6 is in standards compliance mode.. if not, it will also be big.
		Standards compliance mode happens when you use xhtml... */
	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" target="_blank" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '

	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var current_header = ', empty($options['collapse_header']) ? 'false' : 'true', ';

		function shrinkHeader(mode)
		{';

	// Guests don't have theme options!!
	if ($context['user']['is_guest'])
		echo '
			document.cookie = "upshrink=" + (mode ? 1 : 0);';
	else
		echo '
			smf_setThemeOption("collapse_header", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
			document.getElementById("upshrink").src = smf_images_url + (mode ? "/upshrink2.gif" : "/upshrink.gif");

			document.getElementById("upshrinkHeader").style.display = mode ? "none" : "";
			document.getElementById("upshrinkHeader2").style.display = mode ? "none" : "";

			current_header = mode;
		}
	// ]]></script>';

	// the routine for the info center upshrink
	echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			var current_header_ic = ', empty($options['collapse_header_ic']) ? 'false' : 'true', ';

			function shrinkHeaderIC(mode)
			{';

	if ($context['user']['is_guest'])
		echo '
				document.cookie = "upshrinkIC=" + (mode ? 1 : 0);';
	else
		echo '
				smf_setThemeOption("collapse_header_ic", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
				document.getElementById("upshrink_ic").src = smf_images_url + (mode ? "/expand.gif" : "/collapse.gif");

				document.getElementById("upshrinkHeaderIC").style.display = mode ? "none" : "";

				current_header_ic = mode;
			}
		// ]]></script>';
echo'<script type="text/javascript" src="', $settings['theme_url'], '/menu.js"></script>';
// Degisken Resim 
echo'
<script type="text/javascript">
<!--
function SwapImage()
{
   var doc=document, args=arguments;
   doc.$imgSwaps = new Array();
   for(var i=2; i<args.length; i+=2)
   {
      var elem=FindObject(args[i]);
      if(elem)
      {
         doc.$imgSwaps[doc.$imgSwaps.length]=elem;
         elem.$src=elem.src;
         elem.src=args[i+1];
      }
   }
}

function FindObject(id, doc)
{
   var child, elem;
   if(!doc)
      doc=document;
   if(doc.getElementById)
      elem=doc.getElementById(id);
   else
   if(doc.layers)
      child=doc.layers;
   else
   if(doc.all)
      elem=doc.all[id];
   if(elem)
      return elem;
   if(doc.id==id || doc.name==id)
      return doc;
   if(doc.childNodes)
      child=doc.childNodes;
   if(child)
   {
      for(var i=0; i<child.length; i++)
      {
         elem=FindObject(id,child[i]);
         if(elem)
            return elem;
      }
   }
   var frm=doc.forms;
   if(frm)
   {
      for(var i=0; i<frm.length; i++)
      {
         var elems=frm[i].elements;
         for(var j=0; j<elems.length; j++)
         {
            elem=FindObject(id,elems[i]);
            if(elem) return elem;
         }
      }
   }
   return null;
}
// -->
</script>';

//START MENU by MJoRaYuLuN
        echo '<script type="text/javascript">
function getposOffset(overlay, offsettype){
var totaloffset=(offsettype=="left")? overlay.offsetLeft : overlay.offsetTop;
var parentEl=overlay.offsetParent;
while (parentEl!=null){
totaloffset=(offsettype=="left")? totaloffset+parentEl.offsetLeft : totaloffset+parentEl.offsetTop;
parentEl=parentEl.offsetParent;
}
return totaloffset;
}

function overlay(curobj, subobjstr, opt_position){
if (document.getElementById){
var subobj=document.getElementById(subobjstr)
subobj.style.display=(subobj.style.display!="block")? "block" : "none"
var xpos=getposOffset(curobj, "left")+((typeof opt_position!="undefined" && opt_position.indexOf("right")!=-1)? -(subobj.offsetWidth-curobj.offsetWidth) : 0)
var ypos=getposOffset(curobj, "top")+((typeof opt_position!="undefined" && opt_position.indexOf("bottom")!=-1)? curobj.offsetHeight : 0)
subobj.style.left=xpos+"px"
subobj.style.top=ypos+"px"
return false
}
else
return true
}

function overlayclose(subobj){
document.getElementById(subobj).style.display="none"
}

</script>';


// Seim Engellemesi by MJoRaYuluN
	if(!($settings['secim_engel']))
	{
echo'<script type="text/javascript">

//form tags to omit in NS6+:
var omitformtags=["input", "textarea", "select"]

omitformtags=omitformtags.join("|")

function disableselect(e){
if (omitformtags.indexOf(e.target.tagName.toLowerCase())==-1)
return false
}

function reEnable(){
return true
}

if (typeof document.onselectstart!="undefined")
document.onselectstart=new Function ("return false")
else{
document.onmousedown=disableselect
document.onmouseup=reEnable
}

</script>';
}


echo'
</head>
<body>';

// Seimli Logo by MJoRaYuluN
		if(!($settings['logo_bolumu']))
	{
	echo '<img src="', $settings['images_url'], '/sitelogo.gif">';
	}
	
		echo '<div class="tborder" ', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' style="width: 100%;"' : '', '>
	 <table border="0" width="100%" cellspacing="1" cellpadding="2"><tr><td class="menutitle" align="center" valign="top" width="8%">';
        // Balat Men by MJoRaYuLuN

                echo '
                                <a href="', $scripturl, '#" onClick="return overlay(this, \'quicklinks\',\'bottom\')"><img src="', $settings['images_url'], '/' . $context['user']['language'] . '/menu.gif"></a>
                <DIV id="quicklinks" style="position:absolute; border: 1px solid #C8C8C8; background-color: #FFFFFF; width: 345px; padding: 2px; display:none">
        <table width="100%" border="0" cellpadding="0" cellspacing="0">
                <tr>
			<td height="20" width="130" align="left" valign="middle" class="alt"><Center>';
// ye Profil Blm by MJoRaYuLuN

if ($context['user']['is_logged'])
{
if (!empty($context['user']['avatar']))

echo '
', $context['user']['avatar']['image'], '';

else

            echo '<img src="' . $settings['images_url'] . '/avataryok.gif" alt="Avatar Yok" title="Avatar Yok" border="0" />'; 
}
if ($context['user']['is_guest'])
echo '<img src="' . $settings['images_url'] . '/ziyaretci.gif" alt="Ziyareti" title="Hogeldiniz Ziyareti" border="0" />';
// ye Blm

echo'</Center></td>
<td height="20" align="left" valign="middle" class="alt"><font style="font-size: 8pt" color="#545454"><b>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<u>', $context['user']['name'] , '</u></b></font><br>';

// Only tell them about their messages if they can read their messages!
if ($context['allow_pm'])
echo  '<font size="1"><img src="', $settings['images_url'], '/menu/a-pm.gif"> <a href="', $scripturl, '?action=pm"><font color="#808080">', $txt['80064'], ' [', $context['user']['messages'], '], ', $txt['80065'], ' [', $context['user']['unread_messages'], ']</font></a><br />
	<img src="', $settings['images_url'], '/menu/a-pm.gif"> <a href="', $scripturl, '?action=unread"><font color="#808080">', $txt['unread_since_visit'], '</font></a><br><img src="', $settings['images_url'], '/menu/a-takvim.gif"> <font color="#808080">' , $context['current_time'], '</font>';

		// Ziyareti iin MJoRaYuLuN
			if ($context['user']['is_guest'])
			echo'
			<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/sha1.js"></script>
				<form action="', $scripturl, '?action=login2" method="post" class="middletext" style="margin: 3px 1ex 1px 0;"', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
					<input type="text" name="user" size="10" /> :',$txt[35],'<br>
					<input type="hidden" name="hash_passwrd" value="" /><br>
					<input type="password" name="passwrd" size="10" /> :',$txt[36],'<br>
					<input type="checkbox" name="cookieneverexp"', $context['never_expire'] ? ' checked="checked"' : '', ' class="check" onclick="this.form.cookielength.disabled = this.checked;" /><font style="font-size: 8pt">',$txt[80059],'</font>
					&nbsp;<input type="submit" value="', $txt[34], '" />
				</form>';
					//Multicolor
				echo'<br>		<form action="', $scripturl, '" method="post" class="smalltext">
							<input style="border: solid 1px #7E7D7D; background-color: #4492DF; color: #ECECEC; width: 15px; font-size: 1px;" type="submit" value="essiz" name="options[theme_color]"/><br>
							<input style="border: solid 1px #7DBF3F; background-color: #7DBF3F; color: #7DBF3F; width: 15px; font-size: 1px;" type="submit" value="e-acikyesil" name="options[theme_color]"/>
							<input style="border: solid 1px #2F8A33; background-color: #2F8A33; color: #2F8A33; width: 15px; font-size: 1px;" type="submit" value="e-yesil" name="options[theme_color]"/>
							<input style="border: solid 1px #44DEDF; background-color: #44DEDF; color: #44DEDF; width: 15px; font-size: 1px;" type="submit" value="e-turkuaz" name="options[theme_color]"/>
							<input style="border: solid 1px #BD3740; background-color: #BD3740; color: #BD3740; width: 15px; font-size: 1px;" type="submit" value="e-kirmizi" name="options[theme_color]"/>
							<input style="border: solid 1px #2C44BC; background-color: #2C44BC; color: #2C44BC; width: 15px; font-size: 1px;" type="submit" value="e-mavi" name="options[theme_color]"/>
							<input style="border: solid 1px #493FBA; background-color: #493FBA; color: #493FBA; width: 15px; font-size: 1px;" type="submit" value="e-mor" name="options[theme_color]"/>
							<input style="border: solid 1px #D643A2; background-color: #D643A2; color: #D643A2; width: 15px; font-size: 1px;" type="submit" value="e-pembe" name="options[theme_color]"/>
							<input style="border: solid 1px #D5E044; background-color: #D5E044; color: #D5E044; width: 15px; font-size: 1px;" type="submit" value="e-sari" name="options[theme_color]"/>
							<input style="border: solid 1px #E19245; background-color: #E19245; color: #E19245; width: 15px; font-size: 1px;" type="submit" value="e-turuncu" name="options[theme_color]"/>
							<input style="border: solid 1px #909090; background-color: #909090; color: #909090; width: 15px; font-size: 1px;" type="submit" value="e-gri" name="options[theme_color]"/>
							<input style="border: solid 1px #000000; background-color: #000000; color: #000000; width: 15px; font-size: 1px;" type="submit" value="e-siyah" name="options[theme_color]"/>
							</form><br>';
		echo'</td></tr>
                <tr>
                        <td class="catbg" height="30" align="left" valign="middle" style="color:#ffffff;">',$txt[80010],'</td><td class="catbg" height="30" align="center" valign="middle" style="color:#ffffff;">',$txt[80011],'</td>
                </tr>';
                echo'<tr>
                        <td class="menubg" height="20" align="left" valign="middle">
				<img src="', $settings['images_url'], '/menu/anasayfa.gif" style="vertical-align: middle;"> <a href="', $scripturl, '?action=home">',$txt[80000],'</td><td class="menubg2" height="20" align="left" valign="middle">';
				if ($context['user']['is_logged'])
			echo''. $settings['ekmenu1'] . '';
                echo'</td></tr>';
		echo'<tr>
                        <td class="menubg" height="20" align="left" valign="middle">
				<img src="', $settings['images_url'], '/menu/yardim.gif" style="vertical-align: middle;"> <a href="', $scripturl, '?action=help">',$txt[80001],'</td><td class="menubg2" height="20" align="left" valign="middle">';
				if ($context['user']['is_logged'])
			echo''. $settings['ekmenu2'] . '';
                echo'</td></tr>';
                		if ($context['user']['is_logged'])
                echo'<tr>
                	<td class="menubg" height="20" align="left" valign="middle">
			<img src="', $settings['images_url'], '/menu/ara.gif" style="vertical-align: middle;"> <a href="', $scripturl, '?action=search">',$txt[80002],'</td>
			<td class="menubg2" height="20" align="left" valign="middle">'. $settings['ekmenu3'] . '
                </td></tr>';
                		if ($context['user']['is_logged'])
		echo'<tr><td class="menubg" height="20" align="left" valign="middle">
				<img src="', $settings['images_url'], '/menu/profil.gif" style="vertical-align: middle;"> <a href="', $scripturl, '?action=profile">',$txt[80003],'</td>
			<td class="menubg2" height="20" align="left" valign="middle">
			'. $settings['ekmenu4'] . '
                </td></tr>';
				if ($context['user']['is_logged'])
                echo'<tr><td class="menubg"  height="20" align="left" valign="middle">
				<img src="', $settings['images_url'], '/menu/msj.gif" style="vertical-align: middle;"> <a href="', $scripturl, '?action=pm">',$txt[80005],' </a>
			</td><td class="menubg2" height="20" align="left" valign="middle">
			'. $settings['ekmenu5'] . '</td></tr>';
							if ($context['allow_admin'])
                echo'<tr>
                        <td class="menubg" height="20" align="left" valign="middle">
				<img src="', $settings['images_url'], '/menu/admin.gif" style="vertical-align: middle;"> <a href="', $scripturl, '?action=admin">',$txt[80004],'</a></td>
			<td class="menubg2" height="20" align="left" valign="middle"></td>
                </tr>';
				if ($context['user']['is_guest'])
			echo'<td class="menubg" height="20" align="left" valign="middle">
				<img src="', $settings['images_url'], '/menu/kayit.gif"  style="vertical-align: middle;"> <a href="', $scripturl, '?action=register">',$txt[80009],'</a>
		</td><td class="menubg2" height="20" align="left" valign="middle"></td></tr>';
			if ($context['allow_calendar'])
                echo'<tr>
                        <td class="menubg" height="20" align="left" valign="middle">
				<img src="', $settings['images_url'], '/menu/takvim.gif" style="vertical-align: middle;"> <a href="', $scripturl, '?action=calendar">',$txt[80006],'</a></td>
			<td class="menubg2" height="20" align="left" valign="middle"></td>
                </tr>';
			if ($context['allow_memberlist'])
                echo'<tr>
                        <td class="menubg" height="20" align="left" valign="middle">
				<img src="', $settings['images_url'], '/menu/uyeler.gif" style="vertical-align: middle;"> <a href="', $scripturl, '?action=mlist">',$txt[80007],'</a></td>
			<td class="menubg2" height="20" align="left" valign="middle"></td>
                </tr>';
		echo'<tr>
		<td class="alt" align="left" valign="middle"><img src="', $settings['images_url'], '/menu/a-ip.gif"  style="vertical-align: middle;"><font style="font-size: 7pt">', $_SERVER['REMOTE_ADDR'], '</font></td>	
		<td class="alt" height="20" align="right" valign="middle">';
				if ($context['user']['is_logged'])
			echo'
                	<img src="', $settings['images_url'], '/menu/cikis.gif" style="vertical-align: middle;"> <a href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '"><font color="#545454">',$txt[80058],'</font></a>';
				if ($context['user']['is_guest'])
			echo '
                	<img src="', $settings['images_url'], '/menu/kyt.gif" style="vertical-align: middle;"> <a href="', $scripturl, '?action=register"><font color="#545454">',$txt[80009],'</font></a>';
		echo'</td></tr></table></DIV>';

			echo'<td class="menutitle" align="center" width="6%" valign="top">
			<a href="', $scripturl, '?action=home"><img id="anasayfa" src="', $settings['images_url'], '/menu/m-anasayfa.gif" alt="AnaSayfa" title="Anasayfa" border="0" onmouseover="SwapImage(1,0,\'anasayfa\',\'' . $settings['images_url'] . '/menu/m-anasayfa2.gif\')" onmouseout="SwapImage(0,0,\'anasayfa\',\'' . $settings['images_url'] . '/menu/m-anasayfa.gif\')"></a><a href="', $scripturl, '?action=help"><img id="yardim" src="', $settings['images_url'], '/menu/m-yardim.gif" alt="Yardm" title="Yardm" border="0" onmouseover="SwapImage(1,0,\'yardim\',\'' . $settings['images_url'] . '/menu/m-yardim2.gif\')" onmouseout="SwapImage(0,0,\'yardim\',\'' . $settings['images_url'] . '/menu/m-yardim.gif\')"></a>';
			if ($context['user']['is_guest'])
			echo'<a href="', $scripturl, '?action=login"><img id="giris" src="', $settings['images_url'], '/menu/m-giris.gif" alt="Giri" title="Giri" border="0" onmouseover="SwapImage(1,0,\'giris\',\'' . $settings['images_url'] . '/menu/m-giris2.gif\')" onmouseout="SwapImage(0,0,\'giris\',\'' . $settings['images_url'] . '/menu/m-giris.gif\')"></a><a href="', $scripturl, '?action=register"><img id="kayit" src="', $settings['images_url'], '/menu/m-kayit.gif" alt="Kayt" title="Kayt" border="0" onmouseover="SwapImage(1,0,\'kayit\',\'' . $settings['images_url'] . '/menu/m-kayit2.gif\')" onmouseout="SwapImage(0,0,\'kayit\',\'' . $settings['images_url'] . '/menu/m-kayit.gif\')"></a>';
			if ($context['user']['is_logged'])
			echo'<a href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '"><img id="cikis" src="', $settings['images_url'], '/menu/m-cikis.gif" alt="',$txt[80058],'" title="',$txt[80058],'" border="0" onmouseover="SwapImage(1,0,\'cikis\',\'' . $settings['images_url'] . '/menu/m-cikis2.gif\')" onmouseout="SwapImage(0,0,\'cikis\',\'' . $settings['images_url'] . '/menu/m-cikis.gif\')"></a>';
			echo' </td><td class="menutitle"><font style="font-size: 8pt">', theme_linktree(), '</font>';

			echo '</form></td></tr></table></div><br>';
		//Navbar Alt Reklam Blm by MJoRaYuLuN
				echo' <Center>'. $settings['navbar_alti'] . '</Center>';


	// Show the menu here, according to the menu sub template.
	template_menu();


	// The main content should go here.
	echo '
	<div id="bodyarea" style="padding: 1ex 0px 2ex 0px;">';
}

function template_main_below()
{
	global $context, $settings, $options, $scripturl, $txt;

	echo '
	</div>';

	// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
	echo '

	<div id="footerarea" style="text-align: center; padding-bottom: 1ex;', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' width: 100%;' : '', '">
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			function smfFooterHighlight(element, value)
			{
				element.src = smf_images_url + "/" + (value ? "h_" : "") + element.id + ".gif";
			}



		// ]]></script>
	<br>
			<font color="#6E6E6E">'. $settings['copyright_ustu'] . '</font><br><br>
		<div class="tborder" ', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? 'style="width: 100%;"' : '', '>
  <table border="0" width="100%" cellspacing="0" cellpadding="0" height="24"  class="titlebg1">  
                        <tr>
                                <td width="28%" valign="middle" align="left">
					<a href="?language=turkish"><img align="middle" src="', $settings['images_url'], '/turkish.gif" width="21" height="13" alt="Turkish" title="Turkish" /></a>   
					<a href="?language=english"><img align="middle" src="', $settings['images_url'], '/english.gif" width="21" height="13" alt="English" title="English" /></a>
                                </td>
                                <td valign="middle" align="center" style="white-space: nowrap;">
                                        <b>', theme_copyright(), '</b>
                                </td>
                                <td width="28%" valign="middle" align="right"><span class="smalltext"><b>
					<a href="', $scripturl, '?action=home">', $txt['80000'],'</a>
                                        <a href="http://www.mysql.com/" target="_blank">Mysql</a>
                                        <a href="http://www.php.net/" target="_blank">Php</a>
                                        <a href="', $scripturl, '?action=.xmlr" target="_blank">Xml</a>
                                        <a href="', $scripturl, '?type=rss;action=.xml" target="_blank">Rss</a>
                                </b></span></td></tr><tr><td align="center" valign="middle" colspan="3">';
                // Show the load time?
        if ($context['show_load_time'])
                echo '<span class="smalltext"><font color="#FFFFFF">', $txt['smf301'], $context['load_time'], $txt['smf302'], $context['load_queries'], $txt['smf302b'], '</font></span><br>';
			echo'</td></tr></table></div>';





	// This is an interesting bug in Internet Explorer AND Safari. Rather annoying, it makes overflows just not tall enough.
	if (($context['browser']['is_ie'] && !$context['browser']['is_ie4']) || $context['browser']['is_mac_ie'] || $context['browser']['is_safari'])
	{
		// The purpose of this code is to fix the height of overflow: auto div blocks, because IE can't figure it out for itself.
		echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[';

		// Unfortunately, Safari does not have a "getComputedStyle" implementation yet, so we have to just do it to code...
		if ($context['browser']['is_safari'])
			echo '
			window.addEventListener("load", smf_codeFix, false);

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if ((codeFix[i].className == "code" || codeFix[i].className == "post" || codeFix[i].className == "signature") && codeFix[i].offsetHeight < 20)
						codeFix[i].style.height = (codeFix[i].offsetHeight + 20) + "px";
				}
			}';
		else
			echo '
			var window_oldOnload = window.onload;
			window.onload = smf_codeFix;

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = codeFix.length - 1; i > 0; i--)
				{
					if (codeFix[i].currentStyle.overflow == "auto" && (codeFix[i].currentStyle.height == "" || codeFix[i].currentStyle.height == "auto") && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0) && (codeFix[i].offsetHeight != 0 || codeFix[i].className == "code"))
						codeFix[i].style.height = (codeFix[i].offsetHeight + 36) + "px";
				}

				if (window_oldOnload)
				{
					window_oldOnload();
					window_oldOnload = null;
				}
			}';

		echo '
		// ]]></script>';
	}

	echo '
	</div>
</body></html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree()
{
	global $context, $settings, $options;

	echo '&nbsp;<img align="bottom" src="', $settings['images_url'], '/board.gif" border="0" />&nbsp;';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" class="nav">' . $tree['name'] . '</a>' : $tree['name'], '</b>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo '&nbsp;>&nbsp;';
	}

	echo '</div>';
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	// Work out where we currently are.
	$current_action = 'home';
	if (in_array($context['current_action'], array('admin', 'ban', 'boardrecount', 'cleanperms', 'detailedversion', 'dumpdb', 'featuresettings', 'featuresettings2', 'findmember', 'maintain', 'manageattachments', 'manageboards', 'managecalendar', 'managesearch', 'membergroups', 'modlog', 'news', 'optimizetables', 'packageget', 'packages', 'permissions', 'pgdownload', 'postsettings', 'regcenter', 'repairboards', 'reports', 'serversettings', 'serversettings2', 'smileys', 'viewErrorLog', 'viewmembers')))
		$current_action = 'admin';
	if (in_array($context['current_action'], array('search', 'admin', 'calendar', 'profile', 'mlist', 'register', 'login', 'pm')))
		$current_action = $context['current_action'];
	if ($context['current_action'] == 'search2')
		$current_action = 'search';
	if ($context['current_action'] == 'theme')
		$current_action = isset($_REQUEST['sa']) && $_REQUEST['sa'] == 'pick' ? 'profile' : 'admin';

	// Are we using right-to-left orientation?
	if ($context['right_to_left'])
	{
		$first = 'last';
		$last = 'first';
	}
	else
	{
		$first = 'first';
		$last = 'last';
	}

	
}

// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $force_reset = false, $custom_td = '')
{
	global $settings, $buttons, $context, $txt, $scripturl;

	// Create the buttons...
	foreach ($button_strip as $key => $value)
	{
		if (isset($value['test']) && empty($context[$value['test']]))
		{
			unset($button_strip[$key]);
			continue;
		}
		elseif (!isset($buttons[$key]) || $force_reset)
			$buttons[$key] = '<a href="' . $value['url'] . '" ' .( isset($value['custom']) ? $value['custom'] : '') . '>' . $txt[$value['text']] . '</a>';

		$button_strip[$key] = $buttons[$key];
	}

	if (empty($button_strip))
		return '<td>&nbsp;</td>';

	echo '
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_' , $context['right_to_left'] ? 'last' : 'first' , '">&nbsp;</td>
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_back">', implode(' &nbsp;|&nbsp; ', $button_strip) , '</td>
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_' , $context['right_to_left'] ? 'first' : 'last' , '">&nbsp;</td>';
}



?>
